@@ -2,5 +2,5 @@ from django.apps import AppConfig
 
 
 class MailAuthWagtail(AppConfig):
-    name = 'mailauth.contrib.wagtail'
-    label = 'mailauth_wagtail'
+    name = "mailauth.contrib.wagtail"
+    label = "mailauth_wagtail"
